<?php

namespace create_phar;

// Does not support flag GLOB_BRACE
function rglob($pattern, $flags = 0) {
    $files = glob($pattern, $flags);
    foreach (glob(dirname($pattern).'/*', GLOB_ONLYDIR|GLOB_NOSORT) as $dir) {
        $files = array_merge($files, rglob($dir.DIRECTORY_SEPARATOR.basename($pattern), $flags));
    }
    return $files;
}

/**
 * Log to stdout
 * @param string $string
 */
function _log(string $string) : void {
    echo $string . PHP_EOL;
}

$srcRoot = "src";
$buildRoot = "build";

_log("cleanup...");

if (file_exists($buildRoot . DIRECTORY_SEPARATOR . "apothee.phar")) {
    unlink($buildRoot . DIRECTORY_SEPARATOR . "apothee.phar");
}

if (!mkdir($buildRoot) && !is_dir($buildRoot)) {
    throw new \RuntimeException(sprintf('Directory "%s" was not created', $buildRoot));
}

_log("Build phar script");

$phar = new \Phar($buildRoot . DIRECTORY_SEPARATOR . "apothee.phar",
    \FilesystemIterator::CURRENT_AS_FILEINFO | \FilesystemIterator::KEY_AS_FILENAME, "apothee.phar");


/**
 * Add files from src directory to Phar
 */
$files = rglob($srcRoot . DIRECTORY_SEPARATOR . '*.php');
foreach($files as $file) {
    $path = explode(DIRECTORY_SEPARATOR, $file);
    array_shift($path);
    $key = implode(DIRECTORY_SEPARATOR, $path);
    _log("including file $file as $key");
    $phar[$key] = file_get_contents($file);
}

$phar->setStub(\Phar::createDefaultStub("index.php"));

_log("done");