<?php


use exceptions\ManifestCheckException;

abstract class ModuleCommon
{
    /**
     * Read a modules manifest file and check if it meets requirements
     * @param string $manifest_path
     * @param string $expected_module_name
     * @param string $_expected_version
     * @return bool
     * @throws ManifestCheckException
     */
    public static function checkManifest(string $manifest_path, string $expected_module_name, string $_expected_version) : bool {
        if (! file_exists($manifest_path)) {
            throw new \Exception("manifest file does not exist: $manifest_path");
        }

        $manifest = yaml_parse_file($manifest_path);

        if (!is_array($manifest)) {
            throw new \Exception("could not parse module manifest");
        }

        if (!array_key_exists("name", $manifest) || $manifest["name"] !== $expected_module_name) {
            throw new ManifestCheckException("name");
        }

        self::warnFieldDoesNotExist($manifest, [
            "description",
            "author",
            "license",
            "type",
            "authors"
        ]);

        return true;
    }

    private static function warnFieldDoesNotExist(array &$manifest, array $fields): void
    {
        foreach ($fields as $field) {
            if (!array_key_exists($field, $manifest)) {
                Common::_log(L_WARNING,"module manifest has no field \"" . $field . "\" (\"" . $manifest["name"] . "\")");
            }
        }
    }
}