<?php


namespace tasks;


use Common;
use exceptions\ModuleInstallException;
use JetBrains\PhpStorm\Pure;
use manifest\Repository;
use ManifestSingleton;
use VariablesSingleton;

class InstallApotheeTask extends InstallTask
{
    #[Pure] public function __construct(string $version = V_LATEST)
    {
        parent::__construct("apothee", "https://gitlab.alexwaresystems.de/apothee/apothee", $version);
    }

    /**
     * @throws ModuleInstallException
     */
    public function execute(): void
    {
        try {
            Common::_log(L_DEFAULT, "creating configuration directory if it does not exist...");
            // create configuration directory
            if (!is_dir($concurrentDirectory = VariablesSingleton::getVar('configuration_directory')) && !@mkdir($concurrentDirectory) && !is_dir($concurrentDirectory)) {
                throw new \RuntimeException(sprintf('Directory "%s" was not created', $concurrentDirectory));
            }

            Common::_log(L_DEFAULT, "creating library directory if it does not exist...");
            // create lib directory
            if (!is_dir($concurrentDirectory = VariablesSingleton::getVar('library_directory')) && !mkdir($concurrentDirectory) && !is_dir($concurrentDirectory)) {
                throw new \RuntimeException(sprintf('Directory "%s" was not created', $concurrentDirectory));
            }

            Common::_log(L_DEFAULT, "creating public directory if it does not exist...");
            if (!is_dir($concurrentDirectory = VariablesSingleton::getVar('public_directory')) && !mkdir($concurrentDirectory) && !is_dir($concurrentDirectory)) {
                throw new \RuntimeException(sprintf('Directory "%s" was not created', $concurrentDirectory));
            }


            Common::_log(L_DEFAULT, "creating public static directory if it does not exist...");
            if (!is_dir($concurrentDirectory = VariablesSingleton::getVar("public_directory") . DIRECTORY_SEPARATOR . "static") && !mkdir($concurrentDirectory) && !is_dir($concurrentDirectory)) {
                throw new \RuntimeException(sprintf('Directory "%s" was not created', $concurrentDirectory));
            }

            /**
             * TODO make index php require_once statement compatible with library directory change
             */
            Common::_log(L_DEFAULT, "generating index.php...");
            $index_php_contents = "<?php require_once \"../lib/apothee/apothee.php\"; \apothee\apothee(); ?>";
            if (! file_put_contents(VariablesSingleton::getVar('public_directory') . DIRECTORY_SEPARATOR . "index.php", $index_php_contents)) {
                throw new \RuntimeException("could not write index.php");
            }

            $default_repository = new Repository("default", "https://gitlab.alexwaresystems.de/apothee");
            ManifestSingleton::getInstance()->addRepository($default_repository);
        } catch (\Exception|\Error $e) {
            throw new ModuleInstallException("apothee", $e);
        }


        parent::execute();  // git clones Apothee framework
    }
}
