<?php

namespace tasks;

use Common;
use exceptions\ModuleInstallException;
use JetBrains\PhpStorm\Pure;

class InstallTask extends ModuleTask
{

    protected ?string $_href = null;
    protected string $_version = V_LATEST;

    #[Pure] public function __construct(string $module_name, string $href = null, string $version = V_LATEST)
    {
        if ($href === null) {
            $arr = explode("|", $module_name, 3);
            if (count($arr) > 1) {
                $this->_href = $arr[1];
            }
            if ($version === V_LATEST && count($arr) > 2) {
                $this->_version = $arr[2];
            } else {
                $this->_version = $version;
            }
            parent::__construct($arr[0]);
        } else {
            $this->_href = $href;
            $this->_version = $version;
            parent::__construct($module_name);
        }

    }

    #[Pure] public function getHref() : ?string {
        return $this->_href;
    }

    #[Pure] public function getVersion() : ?string {
        return $this->_version;
    }

    /**
     * @throws ModuleInstallException
     */
    public function execute() : void
    {
        $human_readable_source = $this->_href ?? "<no source specified>";
        Common::_log(L_DEFAULT, "installing module " . $this->_module_name . " from " . $human_readable_source . " in version " . $this->_version);
        self::install($this->_module_name, $this->_href, $this->_version);
    }
}
