<?php


use exceptions\ManifestCheckException;
use manifest\ApotheeManifest;
use PHPUnit\Framework\TestCase;

/**
 * Class ApotheeManifestTest
 * @coversDefaultClass \manifest\ApotheeManifest
 */
class ApotheeManifestTest extends TestCase
{
    public function setUp(): void
    {
        if (file_exists(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml")) {
            unlink(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        }

        parent::setUp();
    }


    /**
     * @covers \manifest\ApotheeManifest
     * @throws ManifestCheckException
     */
    public function testApotheeManifestReadException(): void {
        $data = <<<MFF
-2--
apothee-version: latest
3:app-name: Unnamed app
required:
- name: homepage
  href: https://gitlab.alexwaresystems.de/alexwaresystems/homepage
  version: latest
..3.
MFF;
        file_put_contents(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml", $data);

        $this->expectException(ManifestCheckException::class);
        $this->expectWarning();

        $manifest = new ApotheeManifest(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        $manifest->__destruct();
    }

    /**
     * @covers \manifest\ApotheeManifest
     */
    public function testApotheeManifestRead(): void {
        $data = <<<MFF
---
apothee-version: latest
app-name: Unnamed app
required:
- name: homepage
  href: https://gitlab.alexwaresystems.de/alexwaresystems/homepage
  version: latest
...
MFF;
        file_put_contents(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml", $data);

        try {
            $manifest = new ApotheeManifest(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        } catch (ManifestCheckException $e) {
            self::fail("Test failed. Could not read manifest file: " . $e->getMessage());
        }

        $required = $manifest->getRequired();

        self::assertCount(1,$required);

    }

    /**
     * @covers \manifest\ApotheeManifest
     */
    public function testManifestWrite(): void {
        try {
            $manifest = new ApotheeManifest(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        } catch (ManifestCheckException $e) {
            self::fail("Test failed. Could not read manifest file: " . $e->getMessage());
        }

        self::assertIsArray($manifest->getRequired());
        self::assertCount(0,$manifest->getRequired());

        $required = new \manifest\Required('test','href');

        $manifest->addRequired($required);

        self::assertIsArray($manifest->getRequired());
        self::assertCount(1,$manifest->getRequired());

        $manifest->__destruct();

        try {
            $manifest = new ApotheeManifest(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        } catch (ManifestCheckException $e) {
            self::fail("Test failed. Could not read manifest file: " . $e->getMessage());
        }

        $m_required = $manifest->getRequired();
        self::assertIsArray($m_required);
        self::assertCount(1,$m_required);
        self::assertInstanceOf(\manifest\Required::class, $m_required[0]);
        self::assertEquals($required->getHref(), $m_required[0]->getHref());
        self::assertEquals($required->getName(), $m_required[0]->getName());

        // Add seconds required item

        $required2 = new \manifest\Required('test2','href2');

        $manifest->addRequired($required2);
        $manifest->__destruct();

        try {
            $manifest = new ApotheeManifest(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        } catch (ManifestCheckException $e) {
            self::fail("Test failed. Could not read manifest file: " . $e->getMessage());
        }

        $m_required = $manifest->getRequired();
        self::assertIsArray($m_required);
        self::assertCount(2,$m_required);

        self::assertInstanceOf(\manifest\Required::class, $m_required[0]);
        self::assertEquals($required->getHref(), $m_required[0]->getHref());
        self::assertEquals($required->getName(), $m_required[0]->getName());
        self::assertInstanceOf(\manifest\Required::class, $m_required[1]);
        self::assertEquals($required2->getHref(), $m_required[1]->getHref());
        self::assertEquals($required2->getName(), $m_required[1]->getName());
    }

    public function tearDown(): void
    {
        unlink(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");

        parent::tearDown();
    }
}