<?php


use PHPUnit\Framework\TestCase;
use tasks\InstallTask;


/**
 * Class CliTest
 * @coversDefaultClass \Cli
 */
class CliTest extends TestCase
{

    public function setUp(): void
    {
        Cli::$tasks = [];
        parent::setUp();
    }

    public function testRunNoArgs(): void
    {
        Cli::run([]);
        self::assertIsArray(Cli::$tasks);
        self::assertCount(0, Cli::$tasks);
    }

    public function testDummyTask(): void
    {
        //$this->expectException(RuntimeException::class);

        //$throwable = new RuntimeException();
        $throwable = null;
        $task = new \tasks\DummyTask($throwable);

        Cli::$tasks = [$task];
        Cli::executeTasks();

        self::assertIsArray(Cli::$tasks);
    }

    public function testArgumentFetch(): void
    {
        $args = [
            'apothee.phar',
            '--install',
            'test',
            'test_2:https:://source.com/source',
            'TestCaseString',
            '-next'
        ];

        $i = 1;
        $e = Cli::argumentFetch(InstallTask::class,$args, $i);

        self::assertEquals(4, $i);

        self::assertCount($e, Cli::$tasks);
        self::assertEquals(3,$e);
    }

    /**
     * @covers \Cli
     */
    public function testParseArgs(): void {
        $args = [
            'apothee.phar',
            '--install',
            'dummy'
        ];
        Cli::parseArgs($args);
        self::assertCount(1, Cli::$tasks);

        $task = Cli::$tasks[0];
        self::assertInstanceOf(InstallTask::class, $task);

        if ($task instanceof InstallTask) {
            self::assertEquals(null, $task->getHref());
            self::assertEquals(V_LATEST, $task->getVersion());
        } else {
            self::fail("Task is not of type InstallTask");
        }
    }

    /**
     * @covers \Cli
     */
    public function testParseArgsWithSource(): void {
        $source = "https:://source.com/source";

        $args = [
            'apothee.phar',
            '--install',
            'dummy|' . $source,
        ];
        Cli::parseArgs($args);
        self::assertCount(1, Cli::$tasks);

        $task = Cli::$tasks[0];
        self::assertInstanceOf(InstallTask::class, $task);

        if ($task instanceof InstallTask) {
            self::assertEquals($source, $task->getHref());
            self::assertEquals(V_LATEST, $task->getVersion());
        } else {
            self::fail("Task is not of type InstallTask");
        }
    }

    /**
     * @covers \Cli
     */
    public function testParseArgsWithSourceAndVersion(): void {
        $source = "https:://source.com/source";
        $version = "2.7.1";

        $args = [
            'apothee.phar',
            '--install',
            'dummy|' . $source . "|" . $version,
        ];
        Cli::parseArgs($args);
        self::assertCount(1, Cli::$tasks);

        $task = Cli::$tasks[0];
        self::assertInstanceOf(InstallTask::class, $task);

        if ($task instanceof InstallTask) {
            self::assertEquals($source, $task->getHref());
            self::assertEquals($version, $task->getVersion());
        } else {
            self::fail("Task is not of type InstallTask");
        }
    }

    /**
     * @covers \Cli::checkExtensionsLoaded
     */
    public function testCheckExtensionsLoaded() : void {
        Cli::checkExtensionsLoaded();
        self::assertTrue(true);
    }
}
