<?php
use PHPUnit\Framework\TestCase;
use tasks\InstallApotheeTask;


/**
 * Class InstallApotheeTaskTest
 * @coversDefaultClass \tasks\InstallApotheeTask
 */
class InstallApotheeTaskTest extends TestCase
{

    public function setUp(): void
    {
        VariablesSingleton::setVar('library_directory', getcwd() . DIRECTORY_SEPARATOR . "tmp" . DIRECTORY_SEPARATOR . "lib");
        VariablesSingleton::setVar('configuration_directory', getcwd() . DIRECTORY_SEPARATOR . "tmp" . DIRECTORY_SEPARATOR . "conf");
        VariablesSingleton::setVar('public_directory', getcwd() . DIRECTORY_SEPARATOR . "tmp" . DIRECTORY_SEPARATOR . "public");
        VariablesSingleton::setVar('verbose', false);

        !is_dir($dir = getcwd() .DIRECTORY_SEPARATOR . "tmp") && mkdir($dir);

        if (file_exists(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml")) {
            unlink(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        }

        parent::setUp();
    }

    public function tearDown(): void
    {
        try {
            Common::deleteDir(getcwd() . DIRECTORY_SEPARATOR . "tmp");
        } catch (Error|Exception) {
            // Symlink deletion failed. Using a cli command to remove everything
            echo "force removing temporary directory";
            exec('rm -rf tmp');
        }

        unlink(getcwd() . DIRECTORY_SEPARATOR . "apothee.yaml");
        parent::tearDown();
    }

    public function testExecute(): void
    {
        $task = new InstallApotheeTask();
        $task->execute();



        $apothee_dir = VariablesSingleton::getVar("library_directory") . DIRECTORY_SEPARATOR . "apothee";
        $config_dir = VariablesSingleton::getVar("configuration_directory");
        $public_directory = VariablesSingleton::getVar("public_directory");
        self::assertDirectoryExists($apothee_dir);
        self::assertDirectoryExists($config_dir);
        self::assertDirectoryExists($public_directory);
        self::assertFileExists($public_directory . DIRECTORY_SEPARATOR . "index.php");
    }
}
